pecos.error\_models.noise\_impl.noise\_sq\_depolarizing
=======================================================

.. automodule:: pecos.error_models.noise_impl.noise_sq_depolarizing







   .. rubric:: Functions

   .. autosummary::

      noise_sq_depolarizing
